'''
A python wrapper for some-random-api

https://some-random-api.ml
'''

from .images import *
from .anime import *
from .fun import *
from .pokemon import *
from .facts import *
from .canvas import *